Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Repo ¶
type Repo struct {
// The URL of the git repository
URL string `json:"url,omitempty"`
// The reference to clone the repository at.
// An empty value means HEAD.
Ref string `json:"ref,omitempty"`
// The period between ref refreshes
RefreshPeriod caddy.Duration `json:"refresh_period,omitempty"`
// contains filtered or unexported fields
}
The `git` filesystem module uses a git repository as the virtual filesystem.
func (Repo) CaddyModule ¶
func (Repo) CaddyModule() caddy.ModuleInfo
This method indicates that the type is a Caddy module. The returned ModuleInfo must have both a name and a constructor function. This method must not have any side-effects.
Click to show internal directories.
Click to hide internal directories.